@@ -3,7 +3,7 @@
   Managing of external processes
 
 
-  Copyright © 2011-5, 2018 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2011-5, 2018-9 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -22,6 +22,9 @@
 
 */
 
+#ifndef _MUNIPACK_CONFIG_H_
+#define _MUNIPACK_CONFIG_H_
+
 #include <wx/wx.h>
 #include <wx/app.h>
 #include <wx/process.h>
@@ -43,45 +46,35 @@ public:
 
   void Write(const char *);
   void Write(const wxString&, ...);
-  /*
-  void WriteOutput(const wxString&);
-  void WriteFile(const wxString&);
-  void WriteFile(const wxString&,const wxString&);
-  void WriteFile(const wxArrayString&);
-  void WriteFiles(const wxArrayString&);
-  */
   int GetExitCode() const { return exitcode; }
-  wxArrayString GetArgs() const { return ArgsBuffer; }
-  wxArrayString GetInput() const { return InputBuffer; }
-  wxArrayString GetOutput() const { return OutputBuffer; }
-  wxArrayString GetErrors() const { return ErrorBuffer; }
-  size_t GetBufferSize() const { return MaxBuffer; }
+  wxArrayString GetInput() const { return Input; }
+  wxArrayString GetOutput() const { return Output; }
+  wxArrayString GetErrors() const { return Error; }
   void AddInput(const wxArrayString&);
   wxString GetCommand() const { return command; }
-
-  void SetBufferSize(size_t i) { MaxBuffer = i; }
+  void SetEcho(bool);
 
 protected:
 
   wxString command;
-  wxArrayString ArgsBuffer,InputBuffer,OutputBuffer,ErrorBuffer;
+  wxArrayString Input,Output,Error;
   int exitcode;
 
 private:
 
-  wxEvtHandler *handler;
   wchar_t **argv;
   wxTimer timer;
   int tick;
   wxStopWatch stopwatch;
-  size_t MaxBuffer, InputIndex;
-  bool killing;
+  size_t Index;
+  bool echo;
 
-  void Flush();
+  void Send();
+  bool Receive();
   void OnTimer(wxTimerEvent&);
-  void OnIdle(wxIdleEvent&);
-  void OnFinish(wxProcessEvent&);
-  bool StopLine(const wxString&, int&);
+  void OnTerminate(int,int);
+  bool StopLine(const wxString&, int&) const;
+  void SaveErrorLog() const;
 
   void SetRuntimeEnvironment();
   void SetFitsKeys();
@@ -93,6 +86,7 @@ public:
   MuniPipe(wxEvtHandler * =0);
   virtual ~MuniPipe();
 
+  void SetHandler(wxEvtHandler *);
   void push(MuniProcess *);
   void Start();
   void Stop();
@@ -102,15 +96,15 @@ public:
   wxArrayString GetOutput() const;
   wxArrayString GetErrors() const;
 
-protected:
-
-  void OnFinish(wxProcessEvent&);
-
 private:
 
-  wxEvtHandler *handler;
+  wxEvtHandler *parent;
   std::queue<MuniProcess *> procs;
   wxArrayString OutputBuffer,ErrorBuffer;
   int exitcode;
 
+  void OnFinish(wxProcessEvent&);
+
 };
+
+#endif
