@@ -2,7 +2,7 @@
 
   Kombine
 
-  Copyright © 2011-3, 2017 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2011-3, 2017-9 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -46,6 +46,12 @@ bool Munipack::kombine(MuniProcess *action, MuniCmdLineParser& cmd)
   if( cmd.Found("rcen",&x) && cmd.Found("dcen",&y) )
     action->Write("CRVAL = %20.15f %20.15f",x,y);
 
+  if( cmd.Found("pm-ra",&x) && cmd.Found("pm-dec",&y) )
+    action->Write("CRMOV = %20.15f %20.15f",x,y);
+
+  if( cmd.Found("pm-jdref",&x) )
+    action->Write("JDREF = %20.15f",x);
+
   if( cmd.Found("scale",&x) )
     action->Write("SCALE = %25.15e",x);
 
@@ -59,23 +65,15 @@ bool Munipack::kombine(MuniProcess *action, MuniCmdLineParser& cmd)
   }
 
   if( cmd.Found("i",&a) || cmd.Found("interpol",&a) )
-    action->Write("INTERPOL = '" + a + "'");
+    action->Write("INTERPOL = '" + a.Upper() + "'");
 
-  if( cmd.Found("adjust") )
-    action->Write("ADJUSTSKY = T");
+  if( cmd.Found("arith") )
+    action->Write("ROBUST = F");
 
-  if( cmd.Found("expomask") )
-    action->Write("EXPOMASK = T");
+  if( cmd.Found("disable-back") )
+    action->Write("BACKGROUND = F");
 
-  if( cmd.Found("average") )
-    action->Write("AVERAGE = T");
-
-  // a FILE *follows* all the above
-  if( cmd.GetParamCount() > 0 ) {
-    action->Write("NFILES = %d",static_cast<int>(cmd.GetParamCount()));
-    for(size_t i = 0; i < cmd.GetParamCount(); i++)
-      WriteFile(action,cmd.GetParam(i));
-  }
+  WriteFiles(action,cmd.GetFiles());
 
   return true;
 }
