@@ -2,7 +2,7 @@
 
   Munipack - command line interface
 
-  Copyright © 2010-2018 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2010-2020 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -48,7 +48,7 @@ bool Munipack::OnInit()
     "bias", "dark", "flat", "phcorr", "colouring",
     "cone", "astrometry", "phcal",
     "votable", "aphot", "gphot", "find", "timeseries", "fits",
-    "kombine", "phfotran", "cross", "artificial", 0
+    "kombine", "phfotran", "cross", "artificial", "sesame", 0
   };
 
   // define actions
@@ -58,7 +58,7 @@ bool Munipack::OnInit()
     &Munipack::phcal, &Munipack::votable, &Munipack::aphot, &Munipack::gphot,
     &Munipack::find, &Munipack::timeseries, &Munipack::fits,
     &Munipack::kombine, &Munipack::phfotran, &Munipack::cross,
-    &Munipack::artificial
+    &Munipack::artificial, &Munipack::sesame
   };
 
   int idxact = -1;
@@ -77,6 +77,7 @@ bool Munipack::OnInit()
   OnInitCmdLine(cmd);
 
   Bind(wxEVT_END_PROCESS,&Munipack::OnFinish,this);
+  pipe.SetHandler(this);
 
   if( cmd.Parse(false) == 0 ) {
 
@@ -93,7 +94,7 @@ bool Munipack::OnInit()
 
     if( idxact != -1 ) {
 
-      // commands to run (with exceptions)
+      // commands to run (including exceptions)
       wxString com(action);
       if( action == "bias" ) com = "dark";
 
@@ -123,11 +124,9 @@ bool Munipack::OnInit()
     else {
 
       if( cmd.Found("version") ) {
-	wxPrintf("%s %s, %s\n%s\n",INFOTEXT,XVERSION,COPYLEFT,INFOTEXTFULL);
-	wxPrintf("Munipack comes with ABSOLUTELY NO WARRANTY.\n");
-	wxPrintf("You may redistribute copies of Munipack\n");
-	wxPrintf("under the terms of the GNU General Public License.\n");
-	wxPrintf("For more information about these matters, see the file named COPYING.\n");
+	wxPrintf("%s %s, %s\n",PACKAGE_NAME,PACKAGE_VERSION,PACKAGE_COPYLEFT);
+	wxPrintf("%s\n\n",PACKAGE_DESCRIPTION);
+	wxPrintf("This program comes with ABSOLUTELY NO WARRANTY;\nfor details, see the GNU General Public License, version 3 or later.\n");
       }
       else
 	cmd.Usage();
