@@ -2,7 +2,7 @@
 
   VO Table manipulations
 
-  Copyright © 2011-3,5,7 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2011-3,5,7-8 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -24,8 +24,6 @@
 #include "munipack.h"
 #include <wx/wx.h>
 #include <wx/filename.h>
-#include <iostream>
-#include <map>
 
 using namespace std;
 
@@ -50,9 +48,6 @@ bool Munipack::votable(MuniProcess *action, MuniCmdLineParser& cmd)
   if( ! type.IsEmpty() )
     action->Write("TYPE = '"+type.Upper()+"'");
 
-  if( cmd.Found("s",&a) )
-    action->Write("SORT = '" + a + "'");
-
   if( cmd.Found("pt",&a) )
     action->Write("PROJ TYPE = '" + a.MakeUpper() + "'");
 
@@ -83,8 +78,7 @@ bool Munipack::votable(MuniProcess *action, MuniCmdLineParser& cmd)
   if( cmd.Found("col-dec",&a) )
     action->Write("COL_DEC = '" + a + "'");
 
-  for(size_t i = 0; i < cmd.GetParamCount(); i++)
-    WriteFile(action,cmd.GetParam(i));
+  WriteFiles(action,cmd.GetFiles());
 
   return true;
 }
