@@ -1,8 +1,8 @@
 /*
 
-  VOTable parser
+  VOTable convertor
 
-  Copyright © 2010 - 2013, 2017 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2010 - 2013, 2017-8 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -41,7 +41,7 @@ public:
   bool OnInit();
   int OnRun();
 private:
-  int vooper();
+  wxString vooper();
 };
 
 IMPLEMENT_APP_CONSOLE(VOTab)
@@ -54,22 +54,28 @@ bool VOTab::OnInit()
 
 int VOTab::OnRun()
 {
-  int exitcode = vooper();
+  wxString msg = vooper();
 
   // Looks strangle? See: cone.cpp.
-
-  fprintf(stderr,"STOP %d\n",exitcode);
-  return exitcode;
+  if( msg == "" )
+    fprintf(stderr,"STOP 0\n");
+  else
+    fprintf(stderr,"STOP '%s'\n",static_cast<const char *>(msg.c_str()));
+  return msg != "";
 }
 
 
-int VOTab::vooper()
+wxString VOTab::vooper()
 {
-  wxString output, backup, type, file, sort;
+  wxString output, type, file;
   wxString pt, mk, ak, dk;
   double pa, pd, ps, ml;
   long pw = -1, ph = -1;
 
+  // limit logging
+  wxLog::SetLogLevel(wxLOG_Message);
+  wxLog::SetVerbose(); // important to activate previous setup
+
   wxFFileInputStream pstream(stdin);
   wxTextInputStream input(pstream);
 
@@ -77,15 +83,17 @@ int VOTab::vooper()
 
     wxString line = input.ReadLine();
 
-    if( line.StartsWith("VERBOSE") && GetBool(line) )
+    if( line.StartsWith("VERBOSE") ) {
+      if( GetBool(line) )
 	wxLog::SetLogLevel(wxLOG_Debug);
+      else
+	wxLog::SetLogLevel(wxLOG_Message);
+      wxLog::SetVerbose(); // important to activate previous setup
+    }
 
     if( line.StartsWith("TYPE") )
       type = GetString(line);
 
-    if( line.StartsWith("SORT") )
-      sort = GetString(line);
-
     if( line.StartsWith("FILE") )
       file = GetString(line);
 
@@ -120,26 +128,60 @@ int VOTab::vooper()
       mk = GetString(line);
 
     if( line.StartsWith("OUTPUT") )
-      GetOutput(line,output,backup);
+      output = GetString(line);
 
   }
 
 
-  wxFFileInputStream istream(file);
-  VOTable vt(istream);
+  if( type == "FITS" && ! output.IsEmpty() ) {
+    FITStable vt(file);
+    return vt.Save(output,true) ? "" : "FITS save failed.";
+  }
 
-  if( ! sort.IsEmpty() )
-    vt.Sort(sort);
+  wxFFile ffile;
+  if( output.IsEmpty() )
+    ffile.Attach(stdout);
+  else
+    ffile.Open(output.c_str(),"w");
 
-  vt.SetProjection(pt);
-  vt.SetProjectionCenter(pa,pd);
-  vt.SetScale(ps);
-  vt.SetMaglim(ml);
-  vt.SetMagkey(mk);
-  vt.SetAlphakey(ak);
-  vt.SetDeltakey(dk);
-  if( pw > 0 && ph > 0 )
-    vt.SetCanvasSize(pw,ph);
+  if( ! ffile.IsOpened() )
+    return "Failed to create or open `"+output+"'.";
 
-  return vt.Save(output,backup,type) ? 0 : 1;
+  wxFFileOutputStream ostream(ffile);
+  if( ! ostream.IsOk() )
+    return "Failed to initialise an output stream.";
+
+  if( type.IsEmpty() || type == "XML" ) {
+    VOTable vt(file);
+    return vt.Save(ostream) ? "" : "XML save failed.";
+  }
+
+  else if( type == "CSV" ) {
+    CSVtable vt(file);
+    return vt.Save(ostream) ? "" : "CSV save failed.";
+  }
+
+  else if( type == "TXT" ) {
+    TXTable vt(file);
+    return vt.Save(ostream) ? "" : "Text save failed.";
+  }
+  else if( type == "SVG" ) {
+    SVGcanvas vt(file);
+
+    vt.SetProjection(pt);
+    vt.SetProjectionCenter(pa,pd);
+    vt.SetScale(ps);
+    vt.SetMaglim(ml);
+    vt.SetMagkey(mk);
+    vt.SetAlphakey(ak);
+    vt.SetDeltakey(dk);
+    if( pw > 0 && ph > 0 )
+      vt.SetCanvasSize(pw,ph);
+
+    return vt.Save(ostream) ? "" : "SVG save failed.";
+  }
+  else
+    return "Type `"+type+"' unrecognized.";
+
+  return "Votable failed.";
 }
