@@ -361,12 +361,14 @@ void MuniAverage::OnFinish(wxProcessEvent& event)
     wxFileName f(dirname,filename[xtype]);
     FitsFile fits(f.GetFullPath());
     if( fits.Status() ) {
-      MuniIcon micon(fits,config->display_colorspace,config->cdatafile,
+      /*
+      MuniIcon micon(fits,config->display_colourspace,config->cdatafile,
 		     config->default_icon,config->table_icon,config->head_icon,
 		     config->icon_size);
       FitsMeta meta(fits,micon.GetIcon(),micon.GetList());
       if( meta.IsOk() )
 	AddMeta(meta);
+      */
     }
   }
 
