@@ -32,24 +32,24 @@ using namespace std;
 
 
 
-// -- colorzication target ---
+// -- colourization target ---
 
-class ColorDropTarget: public wxDropTarget
+class ColourDropTarget: public wxDropTarget
 {
 public:
-  ColorDropTarget(wxWindow *);
+  ColourDropTarget(wxWindow *);
   wxDragResult OnData(wxCoord, wxCoord, wxDragResult);
 
 private:
   wxWindow *target;
 };
 
-ColorDropTarget::ColorDropTarget(wxWindow *w): target(w)
+ColourDropTarget::ColourDropTarget(wxWindow *w): target(w)
 {
   SetDataObject(new MuniDataObjectMeta);
 }
 
-wxDragResult ColorDropTarget::OnData(wxCoord x, wxCoord y, wxDragResult def)
+wxDragResult ColourDropTarget::OnData(wxCoord x, wxCoord y, wxDragResult def)
 {
   if ( !GetData() )
     return wxDragNone;
@@ -59,7 +59,7 @@ wxDragResult ColorDropTarget::OnData(wxCoord x, wxCoord y, wxDragResult def)
   MuniDataObjectMeta *dobj = (MuniDataObjectMeta *) GetDataObject();
   wxASSERT(dobj);
   vector<FitsMeta> slist = dobj->GetMetafitses();
-  if( slist.size() == 1 && slist[0].Type() == FITS_GRAY ) {
+  if( slist.size() == 1 && slist[0].Type() == FITS_GREY ) {
     if( static_cast<MuniColoring *>(target)->SetDropMeta(x,y,slist) )
       result = wxDragCopy;
   }
@@ -78,7 +78,7 @@ MuniColoring::MuniColoring(wxWindow *w, MuniConfig *c):
 {
   SetIcon(config->munipack_icon);
   EnableCloseButton(false);
-  SetDropTarget(new ColorDropTarget(this));
+  SetDropTarget(new ColourDropTarget(this));
 
   Init();
   CreateControls();
@@ -113,14 +113,14 @@ void MuniColoring::CreateControls()
   MuniThumbCanvas *th = new MuniThumbCanvas(this,coloring_icon);
   osizer->Add(th,wxSizerFlags().Center().DoubleBorder());
 
-  wxStaticText *title = new wxStaticText(this,wxID_ANY,"Color picture");
+  wxStaticText *title = new wxStaticText(this,wxID_ANY,"Colour picture");
   title->SetFont(bf);
   osizer->Add(title,wxSizerFlags().DoubleBorder().Align(wxALIGN_CENTER_VERTICAL));
   ysizer->Add(osizer,wxSizerFlags().Center());
 
-  // colorspace
+  // colourspace
   wxBoxSizer *ctrls = new wxBoxSizer(wxHORIZONTAL);
-  ctrls->Add(new wxStaticText(this,wxID_ANY,"Colorspace:"),
+  ctrls->Add(new wxStaticText(this,wxID_ANY,"Colourspace:"),
 	  wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL).Border());
 
   cspace = new wxChoice(this,wxID_ANY,wxDefaultPosition,wxDefaultSize,
@@ -244,13 +244,15 @@ void MuniColoring::OnBandfile(wxFileDirPickerEvent& event)
   wxASSERT(index > -1);
 
   FitsFile fits(event.GetPath());
-  if( fits.IsOk() && fits.Type() == FITS_GRAY ) {
-    MuniIcon micon(fits,config->display_colorspace,config->cdatafile,
+  if( fits.IsOk() && fits.Type() == FITS_GREY ) {
+    /*
+    MuniIcon micon(fits,config->display_colourspace,config->cdatafile,
 		   config->default_icon,config->table_icon,config->head_icon,
 		   config->icon_size);
     FitsMeta meta(fits,micon.GetIcon(),micon.GetList());
     FitsArrayStat array(fits.Hdu(0));
-    SetMeta(index,meta,array.Med(),1.0);
+    */
+    //    SetMeta(index,meta,array.Med(),1.0);
   }
 }
 
@@ -443,9 +445,9 @@ void MuniColoring::SetMeta(int idx, const FitsMeta& meta,
   // statistics
   if( weight < 0.0 ) {
     FitsFile fits(meta.GetURL());
-    if( fits.IsOk() && fits.Type() == FITS_GRAY) {
+    if( fits.IsOk() && fits.Type() == FITS_GREY) {
       FitsArrayStat array(fits.Hdu(0));
-      black = array.Med();
+      //      black = array.Med();
       weight = 1.0;
     }
   }
