@@ -2,7 +2,7 @@
 
   xmunipack - display canvas
 
-  Copyright © 2012-14, 2018-9 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2012-14, 2018-2021 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -38,9 +38,10 @@ using namespace std;
 // -- MuniDisplayCanvas
 
 MuniDisplayCanvas::MuniDisplayCanvas(wxWindow *w, MuniConfig *c):
-  wxScrolledCanvas(w,wxID_ANY),render(0),canvasid(0),
+  wxWindow(w,wxID_ANY),render(0),canvasid(0),
   topwin(GetGrandParent()),config(c),handler(0),
-  xoff(0), yoff(0), value_type(UNIT_COUNT), coo_type(COO_PIXEL),
+  xoff(0), yoff(0), xsubwin(0), ysubwin(0),
+  value_type(UNIT_COUNT), coo_type(COO_PIXEL),
   scaleicon(false), shrink(1),zoom(1),
   zooming(false), shrinking(false),tunning(false), completed(false),
   dragging(false),invoking(false), rendering(false), finished(false),
@@ -54,7 +55,7 @@ MuniDisplayCanvas::MuniDisplayCanvas(wxWindow *w, MuniConfig *c):
   pal.SetInverse(config->display_palinv);
 
   Bind(wxEVT_CLOSE_WINDOW,&MuniDisplayCanvas::OnClose,this);
-  Bind(wxEVT_SIZE,&MuniDisplayCanvas::OnSize,this);
+  //  Bind(wxEVT_SIZE,&MuniDisplayCanvas::OnSize,this);
   Bind(wxEVT_PAINT,&MuniDisplayCanvas::OnPaint,this);
   Bind(wxEVT_IDLE,&MuniDisplayCanvas::OnIdle,this);
   Bind(EVT_RENDER,&MuniDisplayCanvas::OnRenderFinish,this);
@@ -78,6 +79,7 @@ MuniDisplayCanvas::MuniDisplayCanvas(wxWindow *w, MuniConfig *c):
   Bind(wxEVT_LEFT_UP,&MuniDisplayCanvas::OnLeftUp,this);
   Bind(wxEVT_LEFT_DOWN,&MuniDisplayCanvas::OnClick,this);
   Bind(EVT_TUNE,&MuniDisplayCanvas::OnTuneFine,this);
+  Bind(EVT_ZOOM,&MuniDisplayCanvas::OnZoom,this);
 
 }
 
@@ -109,6 +111,11 @@ void MuniDisplayCanvas::OnIdle(wxIdleEvent& event)
 {
   //  wxLogDebug("MuniDisplayCanvas::OnIdle");
 
+  /*
+  wxSize s = GetSize();
+  wxLogDebug("%d %d",s.GetWidth(),s.GetHeight());
+  */
+
   // Rendering is started by Idle event FOLLOWING all resize(!) events
   // The canvas with a right size is prepared for drawing.
 
@@ -135,41 +142,116 @@ void MuniDisplayCanvas::OnIdle(wxIdleEvent& event)
 
 void MuniDisplayCanvas::OnSize(wxSizeEvent& event)
 {
-  UpdateScroll();
+  /*
+  wxSize s = event.GetSize();
+  wxLogDebug("%d %d",s.GetWidth(),s.GetHeight());
+  */
+  //  UpdateScroll();
+  event.Skip();
 }
 
 void MuniDisplayCanvas::OnPaint(wxPaintEvent& event)
 {
   //  wxLogDebug("MuniDisplayCanvas::OnPaint");
 
+  // display size
+  wxSize size = GetSize();
+  int width = size.GetWidth();
+  int height = size.GetHeight();
+
   wxPaintDC dc(this);
-  DoPrepareDC(dc);
-
-  if( zoom > 1 )
-    dc.SetUserScale(double(zoom),double(zoom));
-
+  //dc.SetLogicalScale(1.0/zoom,1.0/zoom);
   if( pal.GetInverse() )
     dc.SetBackground(*wxWHITE_BRUSH);
   else
-    dc.SetBackground(*wxBLACK_BRUSH);
+    //    dc.SetBackground(*wxBLACK_BRUSH);
+    dc.SetBackground(wxColour("grey15"));
 
-  dc.Clear();
+  if( canvas.IsOk() ) {
+    wxBitmap bmp(canvas);
+    wxMemoryDC mdc(bmp);
 
+    // image size
+    int iwidth = fitsimage.GetWidth();
+    int iheight = fitsimage.GetHeight();
+
+    double sx = double(width) / double(zoom*iwidth);
+    double sy = double(height) / double(zoom*iheight);
+    sx = wxMin(sx,1.0);
+    sy = wxMin(sy,1.0);
+
+    int w = zoom*iwidth;
+    int h = zoom*iheight;
+    int swidth = int(iwidth*sx + 0.5);
+    int sheight= int(iheight*sy + 0.5);
+    xoff = wxMax((width-w)/2,0);
+    yoff = wxMax((height-h)/2,0);
+
+    /*
+    wxLogDebug("MuniDisplayCanvas::OnPaint %d %d %d %d",
+	       iwidth,iheight,swidth,sheight);
+    */
+
+    /*
+    if( zoom > 1 )
+      dc.StretchBlit(xoff,yoff,w,h,&mdc,0,0,iwidth,iheight);
+    else
+      dc.Blit(xoff,yoff,iwidth,iheight,&mdc,0,0);
+
+    dc.SetBrush(*wxTRANSPARENT_BRUSH);
+    dc.SetPen(*wxYELLOW_PEN);
+
+    if( shrink > 1 )
+      dc.DrawRectangle(xoff+xsubwin,yoff+ysubwin,iwidth/shrink,iheight/shrink);
+    else if( zoom > 1 )
+      dc.DrawRectangle(xoff+xsubwin,yoff+ysubwin,width,height);
+    else
+      dc.DrawRectangle(xoff+xsubwin,yoff+ysubwin,iwidth,iheight);
+
+    return;
+    */
+
+
+    if( zoom > 1 ) {
+      //      wxLogDebug("%d %d %d %d %d",width,height,iwidth,iheight,zoom);
+      w = wxMin(w,width);
+      h = wxMin(h,height);
+      double r = double(width) / double(height);
+      swidth = int(width/zoom + 0.5) + 1;
+      sheight = int(swidth/r + 0.5);
+      dc.StretchBlit(xoff,yoff,w,h,&mdc,xsubwin,ysubwin,swidth,sheight);
+    }
+    else {
+      w = iwidth/shrink;
+      h = iheight/shrink;
+      xoff = wxMax((width-w)/2,0);
+      yoff = wxMax((height-h)/2,0);
+      dc.Blit(xoff,yoff,w,h,&mdc,xsubwin,ysubwin);
+    }
+  }
+
+  //  dc.Clear();
+
+  /*
   if( canvas.IsOk() )
     dc.DrawBitmap(wxBitmap(canvas),xoff,yoff);
-
+  */
   // Layers
+  /*
   list<MuniLayer>::const_iterator i;
   for(i = layers.begin(); i != layers.end(); ++i)
     DrawLayer(dc,*i);
+  */
 
   return;
 
   // it's kept for later development
 
   int x0,y0,wc,hc;
+  /*
   GetViewStart(&x0,&y0);
   GetClientSize(&wc,&hc);
+  */
 
   wxRegionIterator upd = GetUpdateRegion();
   while(upd) {
@@ -231,11 +313,14 @@ void MuniDisplayCanvas::SetHdu(const FitsArray& a, const wxImage& i)
   fitsimage = FitsImage(array);
   wxASSERT(fitsimage.IsOk());
 
+  /*
   FitsArray stat(array.IsColour() ? array.Plane(1) : array);
   tone.Setup(stat.Npixels(),stat.PixelData());
+  */
+  tone = FitsTone(array);
 
   // Init canvas
-  shrink = 1;
+  //  shrink = 1;
   InitCanvas();
   //  rendering = true;
   shrinking = true;
@@ -252,10 +337,10 @@ void MuniDisplayCanvas::InitCanvas()
 {
   canvasid = 007;
   //  shrink = 1;
-  zoom = 1;
+  //  zoom = 1;
   canvas = icon.Scale(fitsimage.GetWidth()/shrink,fitsimage.GetHeight()/shrink);
-  SetVirtualSize(canvas.GetWidth(),canvas.GetHeight());
-  UpdateScroll();
+  //  SetVirtualSize(canvas.GetWidth(),canvas.GetHeight());
+  //  UpdateScroll();
 }
 
 void MuniDisplayCanvas::UpdateCanvas(int shrink, int zoom)
@@ -266,7 +351,7 @@ void MuniDisplayCanvas::UpdateCanvas(int shrink, int zoom)
     if( shrink >= 1 )
       canvas.Rescale(w/shrink,h/shrink);
   }
-  SetVirtualSize(zoom*canvas.GetWidth(),zoom*canvas.GetHeight());
+  //  SetVirtualSize(zoom*canvas.GetWidth(),zoom*canvas.GetHeight());
 
   canvasid = canvasid + 1;
 }
@@ -281,9 +366,9 @@ void MuniDisplayCanvas::Reset()
 {
   StopRendering();
 
-  itt.Reset();
-  pal.Reset();
-  color.Reset();
+  //  itt.Reset();
+  //  pal.Reset();
+  //  color.Reset();
   tone.Reset();
   pal.SetPalette(config->display_pal);
 
@@ -329,15 +414,18 @@ void MuniDisplayCanvas::OnSubRender(MuniRenderEvent& event)
 
   if( img.IsOk() && canvas.IsOk() ) {
     /*
-    wxLogDebug("MuniDisplayCanvas::OnSubRender %d %d %d %d %d",
+    wxLogDebug("MuniDisplayCanvas::OnSubRender %d %d %d %d",
 	       (int)event.x,(int)event.y,
 	       (int)event.x + img.GetWidth(),
-	       (int)event.y + img.GetHeight(),int(ren));
-    */
+	       (int)event.y + img.GetHeight());
     wxASSERT(event.x >= 0 &&  event.y >= 0 &&
 	     event.x + img.GetWidth() <= canvas.GetWidth() &&
 	     event.y + img.GetHeight() <= canvas.GetHeight() );
-    canvas.Paste(img,event.x,event.y);
+    */
+    if( event.x >= 0 &&  event.y >= 0 &&
+	     event.x + img.GetWidth() <= canvas.GetWidth() &&
+	event.y + img.GetHeight() <= canvas.GetHeight() )
+      canvas.Paste(img,event.x,event.y);
   }
 
   Refresh();
@@ -435,7 +523,7 @@ void MuniDisplayCanvas::DrawLayer(wxPaintDC& dc, const MuniLayer& layer)
 
   // Find Out where the window is scrolled to
   //  vbX,vbY;                     // Top left corner of client
-  GetViewStart(&vbX,&vbY);
+  //  GetViewStart(&vbX,&vbY);
   /*
   vbX = 0;
   vbY = 0;
@@ -774,7 +862,7 @@ void MuniDisplayCanvas::OnMouseMotion(wxMouseEvent& event)
   if( astrometry ) return;
 
   wxClientDC dc(this);
-  DoPrepareDC(dc);
+  //  DoPrepareDC(dc);
 
   if( event.Moving() ) {
 
@@ -802,12 +890,12 @@ void MuniDisplayCanvas::OnMouseMotion(wxMouseEvent& event)
     else if( dragging ) {
 
       int x0,y0,dx,dy;
-      GetViewStart(&x0,&y0);
-      GetScrollPixelsPerUnit(&dx,&dy);
+      //      GetViewStart(&x0,&y0);
+      //      GetScrollPixelsPerUnit(&dx,&dy);
       if( dx > 0  && dy > 0 ) {
 	int i = x0 - (event.GetLogicalPosition(dc).x - xdrag0) / dx;
 	int j = y0 - (event.GetLogicalPosition(dc).y - ydrag0) / dy;
-	Scroll(i,j);
+	//	Scroll(i,j);
       }
     }
 
@@ -882,9 +970,11 @@ void MuniDisplayCanvas::OnClipValue(wxCommandEvent& event)
 
   wxString val;
   if( array.IsColour() ) {
+    /*
     val =       "X = " + value.Get_str(p.x,p.y,2);
     val = val + " Y = " + value.Get_str(p.x,p.y,1);
     val = val + " Z = " + value.Get_str(p.x,p.y,0);
+    */
   }
   else
     val = value.Get_str(p.x,p.y);
@@ -1004,23 +1094,31 @@ void MuniDisplayCanvas::UpdateScale(int s)
   if( s > 0 ) {
     shrink = s;
     zoom = 1;
-    wxLogDebug("MuniDisplayCanvas::OnTuneFine shrink: 1:%d",shrink);
+    wxLogDebug("MuniDisplayCanvas::UpdateScale shrink: 1:%d",shrink);
   }
   else {
     shrink = 1;
     zoom = abs(s);
-    wxLogDebug("MuniDisplayCanvas::OnTuneFine zoom: %d:1",zoom);
+    wxLogDebug("MuniDisplayCanvas::UpdateScale zoom: %d:1",zoom);
   }
 
   //  rendering = oldshrink != 1;
   invoking = oldshrink != 1;
+
+  if( invoking ) {
+    shrinking = true;
+    tunning = true;
+  }
+
   wxLogDebug("MuniDisplayCanvas::UpdateScale: %d %d %d %d %d",
 	     oldshrink,zoom,completed,rendering,zooming);
 
   UpdateCanvas(shrink,zoom);
-  UpdateScroll();
+  //  UpdateScroll();
+  Refresh();
 }
 
+/*
 void MuniDisplayCanvas::UpdateScroll()
 {
   if( ! canvas.IsOk() ) return;
@@ -1045,6 +1143,7 @@ void MuniDisplayCanvas::UpdateScroll()
 
   Refresh();
 }
+*/
 
 void MuniDisplayCanvas::OnTuneFine(MuniTuneEvent& e)
 {
@@ -1056,16 +1155,16 @@ void MuniDisplayCanvas::OnTuneFine(MuniTuneEvent& e)
 
     // fine tune
   case ID_ITT_TYPE:   itt.SetItt(e.GetString()); found = true; break;
-  case ID_ITT_AMP:    itt.SetAmp(e.x); found = true; break;
-  case ID_ITT_ZERO:   itt.SetZero(e.x); found = true; break;
+    //  case ID_ITT_AMP:    itt.SetAmp(e.x); found = true; break;
+    //  case ID_ITT_ZERO:   itt.SetZero(e.x); found = true; break;
 
-  case ID_COLOR_NITEVISION: color.SetNiteVision(e.GetInt()); found = true;break;
-  case ID_COLOR_SATUR:   color.SetSaturation(e.x); found = true; break;
-  case ID_COLOR_HUE:     color.SetHue(e.x); found = true; break;
-  case ID_COLOR_NITETHRESH: color.SetNiteThresh(e.x); found = true; break;
-  case ID_COLOR_NITEWIDTH:  color.SetNiteWidth(e.x); found = true; break;
-  case ID_COLOR_MEAN:    color.SetLevel(e.index,e.x); found = true; break;
-  case ID_COLOR_WEIGHT:  color.SetWeight(e.index,e.x); found = true; break;
+  case ID_COLOUR_NITEVISION: color.SetNiteVision(e.GetInt()); found = true;break;
+  case ID_COLOUR_SATUR:   color.SetSaturation(e.x); found = true; break;
+  case ID_COLOUR_HUE:     color.SetHue(e.x); found = true; break;
+    //  case ID_COLOUR_NITETHRESH: color.SetNiteThresh(e.x); found = true; break;
+    //  case ID_COLOUR_NITEWIDTH:  color.SetNiteWidth(e.x); found = true; break;
+  case ID_COLOUR_MEAN:    color.SetLevel(e.index,e.x); found = true; break;
+  case ID_COLOUR_WEIGHT:  color.SetWeight(e.index,e.x); found = true; break;
 
   case ID_PALETTE_TYPE:     pal.SetPalette(e.GetString()); found = true; break;
   case ID_PALETTE_INVERSE: pal.SetInverse(e.GetInt()); found = true; break;
@@ -1101,8 +1200,8 @@ void MuniDisplayCanvas::OnTuneFine(MuniTuneEvent& e)
     return;
   }
 
-  if( e.GetId() == ID_ZOOM ) // ignored
-    return;
+  //  if( e.GetId() == ID_ZOOM ) // ignored
+  //    return;
 
   wxLogDebug("WARNING: MuniDisplay::OnTuneFine - reached unknown ID");
 }
@@ -1144,6 +1243,31 @@ void MuniDisplayCanvas::OnAstrometry(MuniAstrometryEvent& e)
   Refresh();
 }
 
+void MuniDisplayCanvas::OnZoom(MuniZoomEvent& e)
+{
+  if( e.GetId() == ID_ZOOMER ) {
+
+    double zoom = e.zoom;
+    if( abs(zoom - 1) < 0.01 )
+      UpdateScale(1);
+    else if( zoom > 1.01 )
+      UpdateScale(-int(zoom+0.5));
+    else // if zoom < 0.99
+      UpdateScale(int(1.0/zoom + 0.5));
+  }
+  else if ( e.GetId() == ID_ZOOMVIEW ) {
+    double width  = fitsimage.GetWidth();
+    double height = fitsimage.GetHeight();
+
+    xsubwin = int(e.x*width/shrink + 0.5);
+    ysubwin = int(e.y*height/shrink+ 0.5);
+
+    Refresh();
+  }
+
+
+}
+
 void MuniDisplayCanvas::OnPhotometry(MuniPhotometryEvent& e)
 {
   wxLogDebug("MuniDisplayCanvas::OnPhotometry %d",(int)e.erase);
