@@ -2,7 +2,7 @@
 
   xmunipack - pre-scaling
 
-  Copyright © 2018-9 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2018-22 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -30,22 +30,53 @@
 
 using namespace std;
 
-FitsTone::FitsTone():
-  initialised(false),
-  black(0.0),qblack(QBLACK),sense(1.0),rsense(1.0),refsense(1.0) {}
+FitsTone::FitsTone(): initialised(false), black(0.0),qblack(QBLACK),
+		      sense(1.0),rsense(1.0),refsense(1.0),refblack(0.0),
+		      refqblack(QBLACK) {}
 
 FitsTone::FitsTone(const FitsArray& array):
-  initialised(false),
-  black(0.0),qblack(QBLACK),sense(1.0),rsense(1.0),refsense(1.0)
+  initialised(false), black(0.0),qblack(QBLACK),sense(1.0),rsense(1.0),refsense(1.0),
+  refblack(0.0),refqblack(QBLACK)
 {
-  Setup(array.Npixels(),array.PixelData());
+  wxASSERT(array.IsOk());
+
+  bool iscolour = array.GetKey("CSPACE").Matches("*XYZ*") && array.GetDepth() == 3;
+
+  wxLogDebug("FitsTone::FitsTone(const FitsArray&): %d %d",
+	     int(array.GetDepth()),iscolour);
+
+  int k = iscolour ? 1 : 0;
+  long npix = array.GetWidth()*array.GetHeight();
+  const float *data = array.PixelData() + k*npix;
+  Setup(npix,data,iscolour);
+}
+
+FitsTone::FitsTone(const FitsTone& tone):
+  initialised(tone.initialised), black(tone.black), qblack(tone.qblack),
+  sense(tone.sense),rsense(tone.rsense),refsense(tone.refsense),
+  refblack(tone.refblack),refqblack(tone.refqblack), cdf_back(tone.cdf_back) {}
+
+FitsTone& FitsTone::operator = (const FitsTone& other)
+{
+  if( this != & other ) {
+    initialised = other.initialised;
+    black = other.black;
+    qblack = other.qblack;
+    sense = other.sense;
+    rsense = other.rsense;
+    refsense = other.refsense;
+    refblack = other.refblack;
+    refqblack = other.refqblack;
+    cdf_back = other.cdf_back;
+  }
+  return *this;
 }
 
 FitsTone::FitsTone(long npix, const float *data):
-  initialised(false),
-  black(0.0),qblack(QBLACK),sense(1.0),rsense(1.0),refsense(1.0)
+  initialised(false), black(0.0),qblack(QBLACK),sense(1.0),rsense(1.0),refsense(1.0),
+  refblack(0.0), refqblack(QBLACK)
 {
-  Setup(npix,data);
+  Setup(npix,data,false);
 }
 
 bool FitsTone::IsOk() const
@@ -53,7 +84,7 @@ bool FitsTone::IsOk() const
   return initialised && cdf_back.IsOk();
 }
 
-void FitsTone::Setup(long npix, const float *data)
+void FitsTone::Setup(long npix, const float *data, bool iscolour)
 {
   wxASSERT(npix > 0 && data);
 
@@ -72,7 +103,12 @@ void FitsTone::Setup(long npix, const float *data)
     d[m++] = data[i];
 
   cdf_back = EmpiricalCDF(m,d);
-  black = cdf_back.GetQuantile(QBLACK);
+
+  qblack = QBLACK;
+  black = cdf_back.GetQuantile(qblack);
+  if( iscolour )
+    cdf_back.GetPositiveQuantile(qblack,black);
+
   float med = cdf_back.GetQuantile(0.5);
   float sig = (cdf_back.GetQuantile(0.75) - cdf_back.GetQuantile(0.25))
 		     / (2*0.6745);
@@ -97,7 +133,6 @@ void FitsTone::Setup(long npix, const float *data)
   }
 
   if( n > 0 ) {
-
     EmpiricalCDF cdf_light(n,d);
     refsense = cdf_light.GetQuantile(QSENSE);
 
@@ -106,7 +141,7 @@ void FitsTone::Setup(long npix, const float *data)
 	       med, sig*0.6745, black, refsense, n);
   }
   else if( cdf_back.IsOk() && med > 100*FLT_EPSILON ) {
-    refsense = 3*(cdf_back.GetQuantile(QSENSE)-cdf_back.GetQuantile(1-QSENSE));
+    refsense = 3*(cdf_back.GetQuantile(QSENSE) - cdf_back.GetQuantile(1-QSENSE));
   }
   else {
     // uniform intensity
@@ -114,6 +149,8 @@ void FitsTone::Setup(long npix, const float *data)
   }
   delete[] d;
 
+  refblack = black;
+  refqblack = refqblack;
   sense = refsense;
   rsense = 1;
 
@@ -148,6 +185,7 @@ void FitsTone::SetRsense(float r)
   sense = refsense / rsense;
 }
 
+
 float *FitsTone::Scale(long n, const float *a) const
 {
   wxASSERT(initialised);
@@ -170,11 +208,20 @@ float FitsTone::GetBlackMax() const
   return cdf_back.GetQuantile(0.99);
 }
 
+float FitsTone::GetBackMed() const
+{
+  return cdf_back.GetQuantile(0.5);
+}
+
+float FitsTone::GetBackSig() const
+{
+  return (cdf_back.GetQuantile(0.75) - cdf_back.GetQuantile(0.25)) / (2*0.6745);
+}
 
 void FitsTone::Reset()
 {
-  qblack = QBLACK;
-  black = cdf_back.GetQuantile(qblack);
+  qblack = refqblack;
+  black = refblack;
   sense = refsense;
   rsense = 1.0;
 }
