@@ -546,7 +546,7 @@ void MuniListCtrl::OnView(wxCommandEvent& event)
 
 void MuniListCtrl::SendActivate(long idx)
 {
-  wxASSERT(0 < idx && idx < metalist.size());
+  wxASSERT(0 < idx && idx < (long) metalist.size());
   if( metalist[idx].IsOk() ) {
     wxNotifyEvent event(EVT_LIST_ACTIVATED,ID_VIEW_FILE);
     event.SetString(wxURI::Unescape(metalist[idx].GetFullPath()));
